@@ -175,6 +175,9 @@ func init() {
 	rootCmd.PersistentFlags().IntP("header", "H", 0, "number of header rows to fix")
 	_ = viper.BindPFlag("general.Header", rootCmd.PersistentFlags().Lookup("header"))
 
+	rootCmd.PersistentFlags().IntP("skip-lines", "", 0, "skip the number of liness")
+	_ = viper.BindPFlag("general.SkipLines", rootCmd.PersistentFlags().Lookup("skip-lines"))
+
 	rootCmd.PersistentFlags().BoolP("alternate-rows", "C", false, "alternately change the line color")
 	_ = viper.BindPFlag("general.AlternateRows", rootCmd.PersistentFlags().Lookup("alternate-rows"))
 
