@@ -109,9 +109,8 @@ func (root *Root) goLine(input string) {
 		root.setMessage(ErrInvalidNumber.Error())
 		return
 	}
-
-	root.moveLine(lN - root.Doc.Header - 1)
-	root.setMessage(fmt.Sprintf("Moved to line %d", lN))
+	lN = root.moveLine(lN - 1)
+	root.setMessage(fmt.Sprintf("Moved to line %d", lN+1))
 }
 
 // markLineNum stores the specified number of lines.
@@ -138,7 +137,28 @@ func (root *Root) setHeader(input string) {
 	}
 
 	root.Doc.Header = num
-	root.setMessage(fmt.Sprintf("Set Header %d", num))
+	root.setMessage(fmt.Sprintf("Set header lines %d", num))
+	root.setWrapHeaderLen()
+	root.Doc.ClearCache()
+}
+
+// setSkipLines sets the number of lines to skip.
+func (root *Root) setSkipLines(input string) {
+	num, err := strconv.Atoi(input)
+	if err != nil {
+		root.setMessage(ErrInvalidNumber.Error())
+		return
+	}
+	if num < 0 || num > root.vHight-1 {
+		root.setMessage(ErrOutOfRange.Error())
+		return
+	}
+	if root.Doc.SkipLines == num {
+		return
+	}
+
+	root.Doc.SkipLines = num
+	root.setMessage(fmt.Sprintf("Set skip lines %d", num))
 	root.setWrapHeaderLen()
 	root.Doc.ClearCache()
 }
