@@ -61,6 +61,8 @@ func (root *Root) main(ctx context.Context, quitChan chan<- struct{}) {
 			root.goLine(ev.value)
 		case *headerInput:
 			root.setHeader(ev.value)
+		case *skipLinesInput:
+			root.setSkipLines(ev.value)
 		case *delimiterInput:
 			root.setDelimiter(ev.value)
 		case *tabWidthInput:
@@ -84,7 +86,7 @@ func (root *Root) main(ctx context.Context, quitChan chan<- struct{}) {
 	}
 }
 
-// checkScreen is true if screen is ready.
+// checkScreen returns true if the screen is ready.
 // checkScreen is used in case it is called directly from the outside.
 // True if called from the event loop.
 func (root *Root) checkScreen() bool {
@@ -106,9 +108,10 @@ func (root *Root) Quit() {
 	}
 	ev := &eventAppQuit{}
 	ev.SetEventNow()
-	go func() {
-		root.Screen.PostEventWait(ev)
-	}()
+	err := root.Screen.PostEvent(ev)
+	if err != nil {
+		log.Println(err)
+	}
 }
 
 // Cancel follow mode and follow all mode.
@@ -135,12 +138,15 @@ func (root *Root) follow() {
 	}
 
 	root.onceFollowMode(root.Doc)
+
 	num := root.Doc.BufEndNum()
-	if root.Doc.latestNum != num {
-		root.skipDraw = false
-		root.TailSync()
-		root.Doc.latestNum = num
+	if root.Doc.latestNum == num {
+		return
 	}
+
+	root.skipDraw = false
+	root.TailSync()
+	root.Doc.latestNum = num
 }
 
 // followAll monitors and switches all document updates
@@ -283,9 +289,10 @@ func (root *Root) Search(str string) {
 	root.input.reg = regexpComple(str, root.CaseSensitive)
 	ev := &eventSearch{}
 	ev.SetEventNow()
-	go func() {
-		root.Screen.PostEventWait(ev)
-	}()
+	err := root.Screen.PostEvent(ev)
+	if err != nil {
+		log.Println(err)
+	}
 }
 
 // BackSearch fires a backward search event.
@@ -303,9 +310,10 @@ func (root *Root) BackSearch(str string) {
 	root.input.reg = regexpComple(str, root.CaseSensitive)
 	ev := &eventBackSearch{}
 	ev.SetEventNow()
-	go func() {
-		root.Screen.PostEventWait(ev)
-	}()
+	err := root.Screen.PostEvent(ev)
+	if err != nil {
+		log.Println(err)
+	}
 }
 
 // eventDocument represents a set document event.
@@ -324,9 +332,10 @@ func (root *Root) SetDocument(docNum int) {
 		ev.docNum = docNum
 	}
 	ev.SetEventNow()
-	go func() {
-		root.Screen.PostEventWait(ev)
-	}()
+	err := root.Screen.PostEvent(ev)
+	if err != nil {
+		log.Println(err)
+	}
 }
 
 // eventAddDocument represents a set document event.
@@ -343,9 +352,10 @@ func (root *Root) AddDocument(m *Document) {
 	ev := &eventAddDocument{}
 	ev.m = m
 	ev.SetEventNow()
-	go func() {
-		root.Screen.PostEventWait(ev)
-	}()
+	err := root.Screen.PostEvent(ev)
+	if err != nil {
+		log.Println(err)
+	}
 }
 
 // eventCloseDocument represents a close document event.
@@ -360,9 +370,10 @@ func (root *Root) CloseDocument(m *Document) {
 	}
 	ev := &eventCloseDocument{}
 	ev.SetEventNow()
-	go func() {
-		root.Screen.PostEventWait(ev)
-	}()
+	err := root.Screen.PostEvent(ev)
+	if err != nil {
+		log.Println(err)
+	}
 }
 
 // eventSearchQuit represents a search quit event.
@@ -377,9 +388,10 @@ func (root *Root) searchQuit() {
 	}
 	ev := &eventSearchQuit{}
 	ev.SetEventNow()
-	go func() {
-		root.Screen.PostEventWait(ev)
-	}()
+	err := root.Screen.PostEvent(ev)
+	if err != nil {
+		log.Println(err)
+	}
 }
 
 func (root *Root) cancelWait(cancel context.CancelFunc) error {
